@@ -149,115 +149,6 @@ class Node ( object ) :
         print ( s_inf )
 
 
-class Node ( object ) :
-    def __init__ ( self ) :
-        self.id_          :str   = ""
-        self.label_       :str   = ""
-        self.description_ :str   = ""
-        self.level_       :int   = 0      # NODES ARE MYOPIC
-        self.metrics_     :list  = list()
-        self.links_       :list  = list()
-        self.ascendants_  :list  = list() # INWARD LINKS  , DIRECT ASCENDENCY  ( 1 LEVEL )
-        self.descendants_ :list  = list() # OUTWARD LINKS , DIRECT DESCENDENCY ( 1 LEVEL )
-        self.data_        :dict  = dict() # OTHER THINGS SHOULD BE ALL INFORMATION FLOATING IN USERSPACE
-
-    def can_it_be_root ( self, n:int=1 ) -> bool :
-        return ( len(self.ascendants_) < n )
-
-    def supplement ( self, n:super ) -> None :
-        self.label_       = n.label_
-        self.description_ = n.description_
-        self.level_       = n.level_
-        self.metrics_     = [ *self.metrics_     , *n.metrics_     ]
-        self.links_       = [ *self.links_       , *n.links_       ]
-        self.ascendants_  = [ *self.ascendants_  , *n.ascendants_  ]
-        self.descendants_ = [ *self.descendants_ , *n.descendants_ ]
-        self.data_        = { **self.data_, **n.data_ }
-
-    def assign_all ( self, identification : str ,
-                           links : type(list(str())) ,
-                           label : str = "" ,
-                           description : str = "" ) -> object :
-        # ASSIGNS ALL META DATA AND BIPOLAR LINKS
-        self.set_id( identification )
-        self.add_label( label )
-        self.add_description( description )
-        self.add_links( links , bClear=True )
-        return ( self )
-
-    def set_level ( self,level:int ) -> None :
-        self.level_ = level
-
-    def set_metrics ( self , metrics:list ) -> None :
-        self.metrics_ = [ *self.metrics_ , *metrics ]
-
-    def level ( self ) -> None :
-        return ( self.level_ )
-
-    def get_data ( self ) -> dict :
-        return ( self.data_ )
-
-    def overwrite_data ( self, data:dict ) -> None :
-        self.data_ = data
-
-    def set_id ( self, identification:str ) -> None :
-        self.id_ = identification
-
-    def add_label ( self, label : str ) -> None :
-        self.label_ = label
-
-    def add_description ( self, description : str ) -> None :
-        self.description_ = description
-
-    def identification ( self ) -> str :
-        return ( self.id_ )
-
-    def label ( self ) -> str :
-        return ( self.label_ )
-
-    def description ( self ) -> str :
-        return ( self.description_ )
-
-    def add_link ( self, identification:str , bClear:bool = False , linktype:str = 'links' ) -> None :
-        edges = self.get_links( linktype )
-        if bClear :
-            edges = list()
-        edges .append( identification )
-        self.links_ = list(set( edges ))
-    #
-    # NOTE : list[str] type declaration is not working in Python3.8
-    def add_links ( self, links:type(list(str())), bClear:bool = False , linktype:str = 'links' ) -> None :
-        edges = self.get_links( linktype )
-        if bClear :
-            edges = list()
-        for e in links :
-            edges .append ( e )
-        self.links_ = list(set( edges ))
-
-    def get_links ( self , linktype:str='links' ) -> type(list(str())) :
-        if not linktype in set([ 'links' , 'ascendants' , 'descendants' ]):
-            print ( ' \n\n!!FATAL!!\t' + ', '.join([ 'links' , 'ascendants' , 'descendants' ]) \
-                  + '\t ARE THE ONLY VALID EDGE TYPES (linktype)' )
-            exit ( 1 )
-        if linktype == 'links' :
-            return ( self.links_ )
-        if linktype == 'ascendants' :
-            return ( self.ascendants_  )
-        if linktype == 'descendants' :
-            return ( self.descendants_ )
-
-    def show ( self ) -> None :
-        s_inf = "NODE [" + self.identification() \
-                   + "," + self.label() + "] - " \
-                   + self.description() + "\nEDGES:"
-        for linktype in [ 'links' , 'ascendants' , 'descendants' ] :
-            s_inf += '\n['+linktype+'] : '
-            for l in self.get_links(linktype=linktype) :
-                s_inf += l + '\t'
-        for item in self.get_data().items() :
-            s_inf += '\n'+str(item[0])+'\t'+str(item[1])
-        print ( s_inf )
-
 class ExtendedNode ( Node ) :
     def __init__ ( self ) :
         #
